@@ -26,5 +26,10 @@ class SimpleWellView(TemplateView):
 
 class QuerySetBackedWellView(SimpleWellView, MultipleObjectMixin):
     def get_queryset(self):
-        return self.get_well() \
-                .merge_with(super(QuerySetBackedWellView, self).get_queryset())
+        return self.get_well().items
+
+    def get_well(self):
+        well = super(QuerySetBackedWellView, self).get_well()
+        well.merge_with(super(QuerySetBackedWellView, self).get_queryset())
+        return well
+
